@@ -10,7 +10,7 @@ import pilas
 from pilas import pilasversion
 import sys
 
-class Depurador:
+class Depurador(object):
     """Esta clase permite hacer depuraciones visuales.
     
     La depuracion visual en pilas consiste en poder mostrar informacion
@@ -44,6 +44,7 @@ class Depurador:
 
     def termina_dibujado(self, motor):
         if self.modos:
+            self._mostrar_cantidad_de_actores(motor)
             self._mostrar_cuadros_por_segundo(motor)
             self._mostrar_posicion_del_mouse(motor)
             self._mostrar_nombres_de_modos(motor)
@@ -117,8 +118,15 @@ class Depurador:
         texto = "Cuadros por segundo: %s" %(rendimiento)
         self.lienzo.texto_absoluto(motor, texto, izquierda + 10, abajo + 10, 
                 color=pilas.colores.violeta)
+
+    def _mostrar_cantidad_de_actores(self, motor):
+        izquierda, derecha, arriba, abajo = pilas.utils.obtener_bordes()
+        total_de_actores = len(pilas.actores.todos)
+        texto = "Cantidad de actores: %s" %(total_de_actores)
+        self.lienzo.texto_absoluto(motor, texto, izquierda + 10, abajo + 30, 
+                color=pilas.colores.violeta)
         
-class ModoDepurador:
+class ModoDepurador(object):
     tecla = "F00"
 
     def __init__(self, depurador):
